@@ -1,9 +1,9 @@
 from .central_reach.core import CentralReachCore
-from .central_reach.webrequests import CentralReachRequests
+from .central_reach.requests_core import CentralReachRequestsCore
 from .central_reach.exceptions import CentralReachException, ScheduledMaintenance, BadRequest, EmptyPage
 
 
 __all__ = [
-    'CentralReachCore', 'CentralReachRequests', 'CentralReachException', 'ScheduledMaintenance', 'BadRequest',
+    'CentralReachCore', 'CentralReachRequestsCore', 'CentralReachException', 'ScheduledMaintenance', 'BadRequest',
     'EmptyPage'
 ]
